@@ -19,7 +19,7 @@ class Kavenegar(ABCSmsPanel):
         """
         self.auth = AuthFactory.get("api_key")(api_key)
 
-    def _response_parser(self, resp):
+    def _response_parser(self, resp: requests.Response) -> Response:
         status_code = int(resp.status_code)
         real_response = json.loads(resp.text)
 
